MapScope

Struct MapScope 

pub struct MapScope {
    pub have_plugin: bool,
}
all players in my map

Fields

have_plugin: bool

only send to those that have the same plugin that uses the same channel this was sent from