pub struct MapScope {
pub have_plugin: bool,
}Expand description
all players in my map
Fields
have_plugin: boolonly send to those that have the same plugin that uses the same channel this was sent from